@@ -110,7 +110,7 @@ class CollectionBrowser: public TQVBox
 
         bool m_returnPressed;
 
-        static CollectionBrowser *s_instance;
+        LIBAMAROK_EXPORT static CollectionBrowser *s_instance;
 
     // for CatMenuId
     friend class CollectionItem;
@@ -216,7 +216,7 @@ class CollectionView : public TDEListView, public DropProxyTarget
         int viewMode() const { return m_viewMode; }
 
         // Transform "The Who" -> "Who, The" or the other way
-        static void manipulateThe( TQString &str, bool reverse );
+        LIBAMAROK_EXPORT static void manipulateThe( TQString &str, bool reverse );
 
         void setShowDivider(bool show);
 
