@@ -39,11 +39,11 @@ AMAROK_EXPORT_PLUGIN( MtpMediaDevice )
 #include <collectionbrowser.h>
 
 // KDE
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
-#include <kmessagebox.h>
-#include <ktoolbarbutton.h>
+#include <tdepopupmenu.h>
+#include <tdemessagebox.h>
+#include <tdetoolbarbutton.h>
 #include <ktempdir.h>
 
 // TQt
@@ -75,7 +75,7 @@ MtpMediaDevice::MtpMediaDevice() : MediaDevice()
     m_customButton = true;
     m_transfer = true;
 
-    KToolBarButton *customButton = MediaBrowser::instance()->getToolBar()->getButton( MediaBrowser::CUSTOM );
+    TDEToolBarButton *customButton = MediaBrowser::instance()->getToolBar()->getButton( MediaBrowser::CUSTOM );
     customButton->setText( i18n("Special device functions") );
     TQToolTip::remove( customButton );
     TQToolTip::add( customButton, i18n( "Special functions of your device" ) );
@@ -214,49 +214,49 @@ MediaItem
 
     if( bundle.title().isEmpty() )
     {
-        trackmeta->title = qstrdup( i18n( "Unknown title" ).utf8() );
+        trackmeta->title = tqstrdup( i18n( "Unknown title" ).utf8() );
     }
     else
     {
-        trackmeta->title = qstrdup( bundle.title().utf8() );
+        trackmeta->title = tqstrdup( bundle.title().utf8() );
     }
 
     if( bundle.album().isEmpty() )
     {
-        trackmeta->album = qstrdup( i18n( "Unknown album" ).utf8() );
+        trackmeta->album = tqstrdup( i18n( "Unknown album" ).utf8() );
     }
     else
     {
-        trackmeta->album = qstrdup( bundle.album().string().utf8() );
+        trackmeta->album = tqstrdup( bundle.album().string().utf8() );
     }
 
     if( bundle.artist().isEmpty() )
     {
-        trackmeta->artist = qstrdup( i18n( "Unknown artist" ).utf8() );
+        trackmeta->artist = tqstrdup( i18n( "Unknown artist" ).utf8() );
     }
     else
     {
-        trackmeta->artist = qstrdup( bundle.artist().string().utf8() );
+        trackmeta->artist = tqstrdup( bundle.artist().string().utf8() );
     }
 
     if( bundle.genre().isEmpty() )
     {
-        trackmeta->genre = qstrdup( i18n( "Unknown genre" ).utf8() );
+        trackmeta->genre = tqstrdup( i18n( "Unknown genre" ).utf8() );
     }
     else
     {
-        trackmeta->genre = qstrdup( bundle.genre().string().utf8() );
+        trackmeta->genre = tqstrdup( bundle.genre().string().utf8() );
     }
 
     if( bundle.year() > 0 )
     {
         TQString date;
         TQTextOStream( &date ) << bundle.year() << "0101T0000.0";
-        trackmeta->date = qstrdup( date.utf8() );
+        trackmeta->date = tqstrdup( date.utf8() );
     }
     else
     {
-        trackmeta->date = qstrdup( "00010101T0000.0" );
+        trackmeta->date = tqstrdup( "00010101T0000.0" );
     }
 
     if( bundle.track() > 0 )
@@ -270,7 +270,7 @@ MediaItem
     }
     if( !bundle.filename().isEmpty() )
     {
-        trackmeta->filename = qstrdup( bundle.filename().utf8() );
+        trackmeta->filename = tqstrdup( bundle.filename().utf8() );
     }
     trackmeta->filesize = bundle.filesize();
 
@@ -526,7 +526,7 @@ LIBMTP_album_t
     {
         debug() << "creating new album " << endl;
         album_object = LIBMTP_new_album_t();
-        album_object->name = qstrdup( items->first()->bundle()->album().string().utf8() );
+        album_object->name = tqstrdup( items->first()->bundle()->album().string().utf8() );
         album_object->tracks = (uint32_t *) malloc(items->count() * sizeof(uint32_t));
         int i = 0;
         for( MtpMediaItem *it = dynamic_cast<MtpMediaItem*>(items->first()); it; it = dynamic_cast<MtpMediaItem*>(items->next()) )
@@ -610,7 +610,7 @@ uint32_t
 MtpMediaDevice::createFolder( const char *name, uint32_t parent_id )
 {
     debug() << "Creating new folder '" << name << "' as a child of "<< parent_id << endl;
-    char *name_copy = qstrdup( name );
+    char *name_copy = tqstrdup( name );
     uint32_t new_folder_id = LIBMTP_Create_Folder( m_device, name_copy, parent_id, 0 );
     delete(name_copy);
     debug() << "New folder ID: " << new_folder_id << endl;
@@ -891,7 +891,7 @@ MtpMediaDevice::playlistFromItem( MtpMediaItem *item )
         return;
     m_critical_mutex.lock();
     LIBMTP_playlist_t *metadata = LIBMTP_new_playlist_t();
-    metadata->name = qstrdup( item->text( 0 ).utf8() );
+    metadata->name = tqstrdup( item->text( 0 ).utf8() );
     const int trackCount = item->childCount();
     if (trackCount > 0) {
         uint32_t *tracks = ( uint32_t* )malloc( sizeof( uint32_t ) * trackCount );
@@ -1208,7 +1208,7 @@ MtpMediaDevice::closeDevice()
  * Get the capacity and freespace available on the device, in KB
  */
 bool
-MtpMediaDevice::getCapacity( KIO::filesize_t *total, KIO::filesize_t *available )
+MtpMediaDevice::getCapacity( TDEIO::filesize_t *total, TDEIO::filesize_t *available )
 {
     if( !isConnected() )
         return false;
@@ -1294,7 +1294,7 @@ MtpMediaDevice::rmbPressed( TQListViewItem *qitem, const TQPoint &point, int )
     MtpMediaItem *item = static_cast<MtpMediaItem *>( qitem );
     if( item )
     {
-        KPopupMenu menu( m_view );
+        TDEPopupMenu menu( m_view );
         switch( item->type() )
         {
         case MediaItem::ARTIST:
