@@ -21,12 +21,12 @@
 #include "debug.h"
 #include "collectiondb.h"
 #include "metabundlesaver.h"
-#include <kapplication.h>
-#include <kfilemetainfo.h>
-#include <kio/global.h>
-#include <kio/job.h>
-#include <kio/jobclasses.h>
-#include <kio/netaccess.h>
+#include <tdeapplication.h>
+#include <tdefilemetainfo.h>
+#include <tdeio/global.h>
+#include <tdeio/job.h>
+#include <tdeio/jobclasses.h>
+#include <tdeio/netaccess.h>
 #include <kmdcodec.h>
 #include <tqdeepcopy.h>
 #include <tqfile.h> //decodePath()
@@ -1232,7 +1232,7 @@ MetaBundle::prettyBitrate( int i )
 TQString
 MetaBundle::prettyFilesize( int s )
 {
-    return KIO::convertSize( s );
+    return TDEIO::convertSize( s );
 }
 
 TQString
