@@ -76,7 +76,7 @@ namespace KDE
      * @see KDE::ProgressBar
      */
 
-    class StatusBar : public TQWidget
+    class LIBAMAROK_EXPORT StatusBar : public TQWidget
     {
         Q_OBJECT
   
@@ -122,7 +122,7 @@ namespace KDE
          * Generally you should use these, as it is very easy for a user to not notice
          * statusBar messages.
          */
-        void longMessage( const TQString &text, int type = Information ) LIBAMAROK_EXPORT ;
+        void longMessage( const TQString &text, int type = Information );
 
         void longMessageThreadSafe( const TQString &text, int type = Information );
 
